/* $Id: mthreads.c,v 1.3 1998/02/02 19:37:44 johns Exp $ */

/*
 * Mesa 3-D graphics library
 * Version:  2.6
 * Copyright (C) 1995-1998  Brian Paul
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public
 * License along with this library; if not, write to the Free
 * Software Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 */

/*
 * mthreads.c -- platform dependent thread support for Mesa 
 *
 */

#include <stdio.h>
#include <stdlib.h>

#ifdef THREADS
#include "mthreads.h" 

#ifdef PTHREADS

void MesaInitTSD(MesaTSD * tsd) {
  if (pthread_key_create(&tsd->key, free) != 0) {
    printf("Mesa: thread failed to allocate key for thread specific data.\n");
    exit(-1);
  }
}

void * MesaGetTSD(MesaTSD * tsd) {
  return pthread_getspecific(tsd->key);
}

void MesaSetTSD(MesaTSD * tsd, void * ptr, void (*initfunc)(void)) {
  pthread_once(&tsd->once, initfunc);
  pthread_setspecific(tsd->key, ptr);
}

#endif /* PTHREADS */
#endif /* THREADS */

