/* $Id: mthreads.h,v 1.3 1998/02/02 19:51:40 johns Exp $ */

/*
 * Mesa 3-D graphics library
 * Version:  2.6
 * Copyright (C) 1995-1998  Brian Paul
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public
 * License along with this library; if not, write to the Free
 * Software Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 */

/*
 * mthreads.h -- platform dependent thread support for Mesa 
 *
 */

#ifdef THREADS
#ifdef PTHREADS

#include <pthread.h> /* POSIX threads headers */
typedef struct {
  pthread_key_t  key;
  pthread_once_t once;
} MesaTSD;

#else 

typedef struct {
  int blah;
} MesaTSD;

#endif
#endif

void  MesaInitTSD(MesaTSD *);
void * MesaGetTSD(MesaTSD *);
void   MesaSetTSD(MesaTSD *, void *, void (*initfunc)(void));

